==> jc-1.4.0.tar.gz: gnu/java/io/NullOutputStream.h <==
// public class gnu.java.io.NullOutputStream

// class file dependencies
// @dep_class f463abae3992d288 gnu_java_io_NullOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_java_io_NullOutputStream_H_
#define _JC_gnu_java_io_NullOutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_io_NullOutputStream$sub_refs	_jc_gnu_java_io_NullOutputStream$sub_refs;
typedef struct _jc_gnu_java_io_NullOutputStream$sub_nonrefs	_jc_gnu_java_io_NullOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_io_NullOutputStream$refs	_jc_gnu_java_io_NullOutputStream$refs;
typedef struct _jc_gnu_java_io_NullOutputStream$nonrefs	_jc_gnu_java_io_NullOutputStream$nonrefs;
typedef struct _jc_gnu_java_io_NullOutputStream$object	_jc_gnu_java_io_NullOutputStream$object;

typedef const struct _jc_gnu_java_io_NullOutputStream$vmethods	_jc_gnu_java_io_NullOutputStream$vmethods;
typedef const struct _jc_gnu_java_io_NullOutputStream$vtable	_jc_gnu_java_io_NullOutputStream$vtable;
typedef const struct _jc_gnu_java_io_NullOutputStream$vtype	_jc_gnu_java_io_NullOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_io_NullOutputStream$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_io_NullOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *);
extern void _jc_gnu_java_io_NullOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *);
extern void _jc_gnu_java_io_NullOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, jint);
extern void _jc_gnu_java_io_NullOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_io_NullOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_io_NullOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_io_NullOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_java_io_NullOutputStream$vmethods	gnu_java_io_NullOutputStream;
};

// Vtype
struct _jc_gnu_java_io_NullOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_io_NullOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_NullOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_io_NullOutputStream$refs {
    _jc_gnu_java_io_NullOutputStream$sub_refs	gnu_java_io_NullOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_NullOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_NullOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_java_io_NullOutputStream$sub_nonrefs	gnu_java_io_NullOutputStream;
};

// Object instance structure
struct _jc_gnu_java_io_NullOutputStream$object {
	_jc_gnu_java_io_NullOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_NullOutputStream$vtype	*vtype;
	_jc_gnu_java_io_NullOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_NullOutputStream$vtype _jc_gnu_java_io_NullOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_NullOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_NullOutputStream$class_object;

#endif	/* _JC_gnu_java_io_NullOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/io/NullOutputStream.h <==
// public class gnu.java.io.NullOutputStream

// class file dependencies
// @dep_class f463abae3992d288 gnu_java_io_NullOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_java_io_NullOutputStream_H_
#define _JC_gnu_java_io_NullOutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_io_NullOutputStream$sub_refs	_jc_gnu_java_io_NullOutputStream$sub_refs;
typedef struct _jc_gnu_java_io_NullOutputStream$sub_nonrefs	_jc_gnu_java_io_NullOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_io_NullOutputStream$refs	_jc_gnu_java_io_NullOutputStream$refs;
typedef struct _jc_gnu_java_io_NullOutputStream$nonrefs	_jc_gnu_java_io_NullOutputStream$nonrefs;
typedef struct _jc_gnu_java_io_NullOutputStream$object	_jc_gnu_java_io_NullOutputStream$object;

typedef const struct _jc_gnu_java_io_NullOutputStream$vmethods	_jc_gnu_java_io_NullOutputStream$vmethods;
typedef const struct _jc_gnu_java_io_NullOutputStream$vtable	_jc_gnu_java_io_NullOutputStream$vtable;
typedef const struct _jc_gnu_java_io_NullOutputStream$vtype	_jc_gnu_java_io_NullOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_io_NullOutputStream$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_io_NullOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_NullOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_NullOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_NullOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_NullOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_io_NullOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_io_NullOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_io_NullOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_io_NullOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_java_io_NullOutputStream$vmethods	gnu_java_io_NullOutputStream;
};

// Vtype
struct _jc_gnu_java_io_NullOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_io_NullOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_NullOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_io_NullOutputStream$refs {
    _jc_gnu_java_io_NullOutputStream$sub_refs	gnu_java_io_NullOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_NullOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_NullOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_java_io_NullOutputStream$sub_nonrefs	gnu_java_io_NullOutputStream;
};

// Object instance structure
struct _jc_gnu_java_io_NullOutputStream$object {
	_jc_gnu_java_io_NullOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_NullOutputStream$vtype	*vtype;
	_jc_gnu_java_io_NullOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_NullOutputStream$vtype _jc_gnu_java_io_NullOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_NullOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_NullOutputStream$class_object;

#endif	/* _JC_gnu_java_io_NullOutputStream_H_ */
